@@ -82,7 +82,7 @@ MCMCconf <- setRefClass(
         samplerConfs        = 'ANY',
         samplerExecutionOrder = 'ANY',
         controlDefaults     = 'ANY',
-        namedSamplerLabelMaker = 'ANY',
+        ##namedSamplerLabelMaker = 'ANY',  ## usage long since deprecated (Dec 2020)
         mvSamples1Conf      = 'ANY',
         mvSamples2Conf      = 'ANY'
     ),
@@ -160,7 +160,7 @@ print: A logical argument specifying whether to print the montiors and samplers.
             samplerConfs <<- list()
             samplerExecutionOrder <<- numeric()
             controlDefaults <<- list(...)
-            namedSamplerLabelMaker <<- labelFunctionCreator('namedSampler')
+            ##namedSamplerLabelMaker <<- labelFunctionCreator('namedSampler')  ## usage long since deprecated (Dec 2020)
             for(i in seq_along(control))     controlDefaults[[names(control)[i]]] <<- control[[i]]
             if(identical(nodes, character())) {
                 nodes <- model$getNodeNames(stochOnly = TRUE, includeData = FALSE)
@@ -179,14 +179,55 @@ print: A logical argument specifying whether to print the montiors and samplers.
             
             nodes <- model$topologicallySortNodes(nodes)   ## topological sort
             if(!useNewConfigureMCMC) {
-                if(!(all(model$isStoch(nodes)))) { stop('assigning samplers to non-stochastic nodes: ', paste0(nodes[!model$isStoch(nodes)], collapse=', ')) }    ## ensure all target node(s) are stochastic
-            }
-
-            if(!useNewConfigureMCMC) {
+                if(!(all(model$isStoch(nodes)))) { stop('assigning samplers to non-stochastic nodes: ', paste0(nodes[!model$isStoch(nodes)], collapse=', ')) }
                 isEndNode <- model$isEndNode(nodes)
                 if(useConjugacy) conjugacyResultsAll <- model$checkConjugacy(nodes)
             } else {
+                ## determine node branch points of any trailing model branches of entirely non-data nodes.
+                ## call these posterior predictive branch nodes - they'll get a posterior_predictive_branch sampler.
+                ## convert to node IDs:
                 nodeIDs <- model$expandNodeNames(nodes, returnType = 'ids')
+                nodeIDsOrig <- nodeIDs
+                posteriorPredictiveBranchNodes <- character()
+                anyPPnodes <- any(model$isEndNode(model$getNodeNames(stochOnly = TRUE, includeData = FALSE)))
+                ## DT: decided I didn't like this additional output message below;
+                ##     this isn't the nimbleModel() function, afterall.
+                ##if(!getNimbleOption('MCMCjointlySamplePredictiveBranches') & anyPPnodes) {
+                ##    message('Detected presense of posterior predictive model nodes.  If many predictive nodes exist in a trailing jointly posterior predictive network, then MCMC sampling of these posterior predictive nodes may be improved by enabling the NIMBLE package option \'MCMCjointlySamplePredictiveBranches\' prior to configuring the MCMC algorithm.')
+                ##}
+                if(getNimbleOption('MCMCjointlySamplePredictiveBranches') & anyPPnodes) {
+                    stochNonDataIDs <- model$getNodeNames(stochOnly = TRUE, includeData = FALSE, returnType = 'ids')
+                    ## all potential (candidate) posterior predictive branch nodes:
+                    candidateNodeIDs <- stochNonDataIDs[!model$isEndNode(stochNonDataIDs)]
+                    dataNodeIDs <- model$getNodeNames(dataOnly = TRUE, returnType = 'ids')
+                    dataNodeParentIDs <- model$expandNodeNames(getParentNodes(dataNodeIDs, model, stochOnly = TRUE), returnType = 'ids')
+                    ## remove from candidate nodes all direct parents of data nodes:
+                    candidateNodeIDs <- setdiff(candidateNodeIDs, dataNodeParentIDs)
+                    nCandidate <- length(candidateNodeIDs)
+                    nextCandInd <- 1
+                    posteriorPredictiveBranchNodeIDs <- numeric()
+                    while(nextCandInd <= nCandidate) {
+                        thisCandNodeID <- as.numeric(candidateNodeIDs[nextCandInd])
+                        stochDownstreamNoSelfIDs <- model$getDependencies(thisCandNodeID, self = FALSE, stochOnly = TRUE, downstream = TRUE, returnType = 'ids')
+                        ## skip candidate nodes that have any downstream data nodes:
+                        if(length(intersect(stochDownstreamNoSelfIDs, dataNodeIDs)) > 0)   { nextCandInd <- nextCandInd + 1;   next }
+                        ## skip candidate nodes for which the entire resulting branch wasn't going to be sampled:
+
+                        if(!all(c(thisCandNodeID, stochDownstreamNoSelfIDs) %in% nodeIDsOrig))   { nextCandInd <- nextCandInd + 1;   next }
+                        ## found a posterior predictive branch node:
+                        posteriorPredictiveBranchNodeIDs <- c(posteriorPredictiveBranchNodeIDs, thisCandNodeID)
+                        ## remove stochastic nodes which are within this branch from the nodeIDs to be assigned samplers:
+                        nodeIDs <- setdiff(nodeIDs, stochDownstreamNoSelfIDs)
+                        ## update candidateNodeIDs, removing downstream stochastic dependencies of this branch node from the candidate set:
+                        candidateNodeIDs <- candidateNodeIDs[-(1:nextCandInd)]
+                        candidateNodeIDs <- setdiff(candidateNodeIDs, stochDownstreamNoSelfIDs)
+                        nCandidate <- length(candidateNodeIDs)
+                        nextCandInd <- 1
+                    }
+                    ## convert back to node names:
+                    nodes <- model$expandNodeNamesFromGraphIDs(nodeIDs)
+                    posteriorPredictiveBranchNodes <- model$expandNodeNamesFromGraphIDs(posteriorPredictiveBranchNodeIDs)
+                }
                 isEndNode <-  model$isEndNode(nodeIDs) ## isEndNode can be modified later to avoid adding names when input is IDs
                 if(useConjugacy) conjugacyResultsAll <- nimble:::conjugacyRelationshipsObject$checkConjugacy(model, nodeIDs) ## Later, this can go through model$checkConjugacy if we make it check whether nodes are already nodeIDs.  To isolate changes, I am doing it directly here.
                 nodeDeclIDs <- model$modelDef$maps$graphID_2_declID[nodeIDs] ## Below, nodeDeclIDs[i] gives the nodeDeclID.  We could add an interface to get this.
@@ -266,6 +307,9 @@ print: A logical argument specifying whether to print the montiors and samplers.
                     }
                     ## if node has 0 stochastic dependents, assign 'posterior_predictive' sampler (e.g. for predictive nodes)
                     if(isEndNode[i]) { addSampler(target = node, type = 'posterior_predictive');     next }
+
+                    ## if nodes is a branch point of a network of entirely non-data nodes, assign 'posterior_predictive_branch' sampler
+                    if(node %in% posteriorPredictiveBranchNodes) { addSampler(target = node, type = 'posterior_predictive_branch');     next }
                     
                     ## for multivariate nodes, either add a conjugate sampler, RW_multinomial, or RW_block sampler
                     if(nodeLength > 1) {
@@ -315,7 +359,7 @@ print: A logical argument specifying whether to print the montiors and samplers.
                     ## if node distribution is discrete, assign 'slice' sampler
                     if(discrete) { addSampler(target = node, type = 'slice');     next }
                     
-                    ## if node distribution is dgamma and its dependency is dCRP, assign 'augmented_BetaGamma' sampler
+                    ## if node distribution is dgamma and its dependency is dCRP, assign 'CRP_concentration' sampler
                     if(check_dCRP) {
                         if(nodeDist == 'dgamma'){
                             depNode <- model$getDependencies(node, self=FALSE)
@@ -465,7 +509,7 @@ Invisibly returns a list of the current sampler configurations, which are sample
 
             if(!(all(model$isStoch(target)))) { warning(paste0('No sampler assigned to non-stochastic node: ', paste0(target,collapse=', '))); return(invisible(samplerConfs)) }   ## ensure all target node(s) are stochastic
 
-            ##libraryTag <- if(nameProvided) namedSamplerLabelMaker() else thisSamplerName   ## unique tag for each 'named' sampler, internal use only
+            ##libraryTag <- if(nameProvided) namedSamplerLabelMaker() else thisSamplerName   ## unique tag for each 'named' sampler, internal use only  ## usage long since deprecated (Dec 2020)
             ##if(is.null(controlNamesLibrary[[libraryTag]]))   controlNamesLibrary[[libraryTag]] <<- mcmc_findControlListNamesInCode(samplerFunction)   ## populate control names library
             ##requiredControlNames <- controlNamesLibrary[[libraryTag]]
             controlArgs <- c(control, list(...))
@@ -1070,7 +1114,7 @@ makeNewConfFromOldConf <- function(oldMCMCconf){
     newMCMCconf$samplerConfs <- oldMCMCconf$samplerConfs
     newMCMCconf$samplerExecutionOrder <- oldMCMCconf$samplerExecutionOrder
     newMCMCconf$controlDefaults <- oldMCMCconf$controlDefaults
-    newMCMCconf$namedSamplerLabelMaker <- oldMCMCconf$namedSamplerLabelMaker
+    ##newMCMCconf$namedSamplerLabelMaker <- oldMCMCconf$namedSamplerLabelMaker  ## usage long since deprecated (Dec 2020)
     newMCMCconf$mvSamples1Conf <- oldMCMCconf$mvSamples1Conf
     newMCMCconf$mvSamples2Conf <- oldMCMCconf$mvSamples2Conf
     return(newMCMCconf)	
